@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '3.3.9';
+our $VERSION = '3.4.0';
 
 use Carp              ();
 use File::Spec        ();
@@ -668,7 +668,7 @@ Text::Xslate - Scalable template engine for Perl5
 
 =head1 VERSION
 
-This document describes Text::Xslate version 3.3.9.
+This document describes Text::Xslate version 3.4.0.
 
 =head1 SYNOPSIS
 
@@ -1233,13 +1233,15 @@ A "too-safe" HTML escaping filter which escape all the symbolic characters
 
 WEB: L<http://xslate.org/>
 
-PROJECT HOME: L<http://github.com/xslate/>
+PROJECT HOME: L<https://github.com/xslate/>
 
-REPOSITORY: L<http://github.com/xslate/p5-Text-Xslate/>
+REPOSITORY: L<https://github.com/xslate/p5-Text-Xslate/>
 
 =head1 BUGS
 
-Please make a file on L<http://github.com/xslate/>. Patches are always welcome.
+Please report issues at L<https://github.com/xslate/p5-Text-Xslate/issues>.
+Patches are always welcome.
+
 =head1 SEE ALSO
 
 Documents:
