@@ -3,7 +3,7 @@ package Text::Xslate::PP;
 use 5.008_001;
 use strict;
 
-our $VERSION = '3.3.9';
+our $VERSION = '3.4.0';
 
 BEGIN{
     $ENV{XSLATE} = ($ENV{XSLATE} || '') . '[pp]';
@@ -443,6 +443,11 @@ sub tx_match { # simple smart matching
 
 sub tx_concat {
     my($lhs, $rhs) = @_;
+    if (!defined $lhs){
+        return $rhs;
+    }elsif(!defined $rhs){
+        return $lhs;
+    }
     if(ref($lhs) eq TXt_RAW) {
         if(ref($rhs) eq TXt_RAW) {
             return Text::Xslate::Util::mark_raw(${ $lhs } . ${ $rhs });
@@ -676,7 +681,7 @@ Text::Xslate::PP - Yet another Text::Xslate runtime in pure Perl
 
 =head1 VERSION
 
-This document describes Text::Xslate::PP version 3.3.9.
+This document describes Text::Xslate::PP version 3.4.0.
 
 =head1 DESCRIPTION
 
